# 项目说明
```
https://github.com/bravekingzhang/search-engine-tool 项目的python版本

原项目使用 node + puppeteer 
python版本使用 selenium
```

# 安装
```bash
pip install search-engine-tool

```

# 支持搜索引擎
```
Bing
Google (需要调用方自身能够访问)
Yahoo
```

# todo 
```
1 处理人机验证
2 

```

